@@ -759,6 +759,11 @@ gff_load (GnomeFontFace *face)
 	FT_Error ft_result;
 	static FT_Library ft_library = NULL;
 	GPFontEntry *entry;
+	FT_CharMap found = 0;
+	FT_CharMap charmap;
+	FT_CharMap appleRoman = 0;
+	FT_CharMap symbol = 0;
+	int n;
 
 	if (!ft_library) {
 		ft_result = FT_Init_FreeType (&ft_library);
@@ -809,6 +814,43 @@ gff_load (GnomeFontFace *face)
 
 	face->ft_face = ft_face;
 
+	/* Microsoft symbol and Adobe fontspecific take priority over unicode
+ 	 * so that non lingual fonts work [#80409]
+	 */
+ 	for (n = 0; n < ft_face->num_charmaps; n++) {
+ 		charmap = ft_face->charmaps[n];
+ 
+ 		if ((charmap->platform_id == 7) &&  (charmap->encoding_id == 2))
+ 		{
+ 			found = charmap;
+ 			break;
+ 		}
+ 		else if ((charmap->platform_id == 3) &&  (charmap->encoding_id == 0))
+ 			symbol = charmap;
+ 		else if ((charmap->platform_id == 1) &&  (charmap->encoding_id == 0))
+ 			appleRoman = charmap;
+ 		else if ((charmap->platform_id == 3) &&  (charmap->encoding_id == 1))
+ 			found = charmap;
+ 	}
+ 
+ 	/* If we have no Unicode or AdobeFontspecific, will try Apple roman first,
+	 * followed by symbol.  For TT symbol fonts, apple roman works better?
+	 */
+ 	if ((!found) && (appleRoman))
+		found = appleRoman;
+ 	if ((!found) && (symbol))
+		found = symbol;
+ 
+ 	/* Hope for the best with whatever is the default */
+ 	if (!found) {
+ 		g_warning ("file %s: line %d: Face %s does not have a recognized charmap", __FILE__, __LINE__, entry->name);
+ 	} else {
+ 		ft_result = FT_Set_Charmap (ft_face, found);
+ 		if (ft_result != FT_Err_Ok) {
+ 			g_warning ("file %s: line %d: Face %s could not set charmap", __FILE__, __LINE__, entry->name);
+ 		}
+	}
+	
 	ft_result = FT_Select_Charmap (ft_face, ft_encoding_unicode);
 	if (ft_result != FT_Err_Ok) {
 		g_warning ("file %s: line %d: Face %s does not have unicode charmap", __FILE__, __LINE__, face->entry->name);
