@@ -114,6 +114,11 @@ struct _GnomePrintPdf {
 
         /* We have a default GS which we use in all the pages */     
 	gint object_number_gs;
+
+	/* Contents */
+	gchar *stream;
+	gint   stream_used;
+	gint   stream_allocated;
 };
 
 struct _GnomePrintPdfObject {
@@ -140,10 +145,6 @@ struct _GnomePrintPdfPage {
 	gint object_number_contents;
 	gint object_number_resources;
 
-	/* Contents */
-	gchar *stream;
-	gint   stream_used;
-	gint   stream_allocated;
 };
 
 static void gnome_print_pdf_class_init (GnomePrintPdfClass *klass);
@@ -248,6 +249,10 @@ gnome_print_pdf_init (GnomePrintPdf *pdf)
 	
 	pdf->current_object = 0;
 	pdf->object_number_gs = gnome_print_pdf_object_new (pdf);
+
+	pdf->stream_allocated = GNOME_PRINT_PDF_INITIAL_BUFFER_SIZE;
+	pdf->stream = g_malloc (pdf->stream_allocated);
+	pdf->stream_used = 0;
 }
 
 static void
@@ -291,6 +296,11 @@ gnome_print_pdf_finalize (GObject *object)
 	}
 	g_list_free (pdf->fonts);
 
+	/* Page stream */
+	g_free (pdf->stream);
+	pdf->stream_allocated = 0;
+	pdf->stream_used = 0;
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -653,13 +663,11 @@ gnome_print_pdf_beginpage (GnomePrintContext *pc, const guchar *name)
 	page->object_number_page      = gnome_print_pdf_object_new (pdf);
 	page->object_number_contents  = gnome_print_pdf_object_new (pdf);
 	page->object_number_resources = gnome_print_pdf_object_new (pdf);
-	page->stream_allocated = GNOME_PRINT_PDF_INITIAL_BUFFER_SIZE;
-	page->stream = g_malloc (page->stream_allocated);
-	page->stream[0] = 0;
-	page->stream_used = 0;
 
 	pdf->pages = g_list_prepend (pdf->pages, page);
-	
+
+	pdf->stream_used = 0;
+	pdf->stream[0] = '\0';
 	pdf->selected_font    = NULL;
 	pdf->color_set_fill   = FALSE;
 	pdf->color_set_stroke = FALSE;
@@ -701,7 +709,7 @@ gnome_print_pdf_page_write_contents (GnomePrintPdf *pdf, GnomePrintPdfPage *page
 #endif	
 	case PDF_COMPRESSION_NONE:
 	default:
-		real_length = page->stream_used; 
+		real_length = pdf->stream_used; 
 	}
 	
 	ret += gnome_print_pdf_object_start (pdf, page->object_number_contents, FALSE);
@@ -715,10 +723,10 @@ gnome_print_pdf_page_write_contents (GnomePrintPdf *pdf, GnomePrintPdfPage *page
 		ret += gnome_print_pdf_write  (pc, EOL);
 	}
 #endif	
-	gnome_print_pdf_fprintf (pdf,"/Length %d" EOL, page->stream_used);
+	gnome_print_pdf_fprintf (pdf,"/Length %d" EOL, pdf->stream_used);
 	gnome_print_pdf_fprintf (pdf,">>" EOL);
 	gnome_print_pdf_fprintf (pdf,"stream" EOL);
-	gnome_print_pdf_print_sized (pdf, page->stream, page->stream_used);
+	gnome_print_pdf_print_sized (pdf, pdf->stream, pdf->stream_used);
 	gnome_print_pdf_fprintf (pdf, "endstream" EOL);
 	gnome_print_pdf_fprintf (pdf, "endobj" EOL);
 	ret += gnome_print_pdf_object_end (pdf, page->object_number_contents, TRUE);
@@ -813,14 +821,12 @@ gnome_print_pdf_showpage (GnomePrintContext *pc)
 	gnome_print_pdf_page_write_resources (pdf, page);
 	
 	page->shown = TRUE;
-	g_free (page->stream);
-	page->stream = NULL;
-	page->stream_used = 0;
-	page->stream_allocated = 0;
+
 	g_list_free (page->images);
 
 	gnome_print_pdf_graphic_mode_set (pdf, PDF_GRAPHIC_MODE_GRAPHICS);
 	
+	pdf->stream_used = 0;
 	pdf->selected_font    = NULL;
 	pdf->color_set_fill   = FALSE;
 	pdf->color_set_stroke = FALSE;
@@ -1377,12 +1383,13 @@ gnome_font_face_get_pdf_flags (GnomeFontFace *face)
  * @rect: 
  * 
  * Freetype is returning some invalid numbers for the font's BBox
- * clean the numbers. FIXME in the correct way (tracking the bug down)
+ * clean the numbers, we need this work around because even if
+ * freetype fixes it, there are still versions deployed that have
+ * it.
  **/
 static void
 my_fix_drect (ArtDRect *rect)
 {
-
 #define TOO_BIG(x)    (x>100000)
 #define TOO_SMALL(x) (x<-100000)
 	if (TOO_BIG (rect->x0) ||
@@ -1767,17 +1774,17 @@ gnome_print_pdf_page_fprintf (GnomePrintPdf *pdf, const char *format, ...)
 	/* Write it */
 	len = strlen (text);
 	page = pdf->pages->data;
-	if ((page->stream_used + len + 1) > page->stream_allocated) {
-		while ((page->stream_used + len) > page->stream_allocated) {
-			page->stream_allocated += grow_size;
+	if ((pdf->stream_used + len + 1) > pdf->stream_allocated) {
+		while ((pdf->stream_used + len) > pdf->stream_allocated) {
+			pdf->stream_allocated += grow_size;
 			grow_size <<= 1;
 		}
-		page->stream = g_realloc (page->stream, page->stream_allocated);
+		pdf->stream = g_realloc (pdf->stream, pdf->stream_allocated);
 	}
 
-	memcpy (page->stream + page->stream_used, text, len * sizeof (gchar));
-	page->stream_used += len;
-	page->stream [page->stream_used] = 0;
+	memcpy (pdf->stream + pdf->stream_used, text, len * sizeof (gchar));
+	pdf->stream_used += len;
+	pdf->stream [pdf->stream_used] = 0;
 	g_free (text);
 	
 	return len;
