@@ -28,12 +28,11 @@
 
 #define __GNOME_PRINT_PS2_C__
 
-#include <config.h>
+#include "config.h"
 
 #include <math.h>
 #include <string.h>
 #include <time.h>
-#include <stdio.h>
 #include <unistd.h>
 #include <locale.h>
 
@@ -53,10 +52,35 @@
 typedef struct _GnomePrintPs2Font GnomePrintPs2Font;
 typedef struct _GnomePrintPs2Page GnomePrintPs2Page;
 
+struct _GnomePrintPs2Class {
+	GnomePrintContextClass parent_class;
+};
+
+struct _GnomePrintPs2 {
+	GnomePrintContext pc;
+
+	/* Bounding box */
+	ArtDRect bbox;
+
+	/* lists */
+	GnomePrintPs2Font *fonts;
+	GnomePrintPs2Page *pages;
+
+	/* State */
+	GnomePrintPs2Font *selected_font;
+	gdouble r, g, b;
+	gint private_color_flag;
+	gint gsave_level;
+	
+	/* Buffer */
+	FILE *buf;
+	gchar *bufname;
+};
+
 struct _GnomePrintPs2Font {
 	GnomePrintPs2Font *next;
 	GnomeFontFace *face;
-	GFPSObject *pso;
+	GnomeFontPsObject *pso;
 	gdouble currentsize;
 };
 
@@ -68,31 +92,6 @@ struct _GnomePrintPs2Page {
 	GSList *usedfonts;
 };
 
-struct _GnomePrintPs2 {
-	GnomePrintContext pc;
-
-	/* List of used fonts */
-	GnomePrintPs2Font *fonts;
-	/* Active font */
-	GnomePrintPs2Font *selectedfont;
-	/* Active color */
-        gdouble r, g, b;
-	gint private_color_flag;
-	/* List of pages */
-	GnomePrintPs2Page *pages;
-	/* Bookkeeping */
-	gint gsave_level;
-	/* Size of printed area */
-	ArtDRect bbox;
-	/* Buffer */
-	FILE *buf;
-	gchar *bufname;
-};
-
-struct _GnomePrintPs2Class {
-	GnomePrintContextClass parent_class;
-};
-
 static void gnome_print_ps2_class_init (GnomePrintPs2Class *klass);
 static void gnome_print_ps2_init (GnomePrintPs2 *ps2);
 static void gnome_print_ps2_finalize (GObject *object);
@@ -113,13 +112,13 @@ static gint gnome_print_ps2_set_color (GnomePrintPs2 *ps2);
 static gint gnome_print_ps2_set_line (GnomePrintPs2 *ps2);
 static gint gnome_print_ps2_set_dash (GnomePrintPs2 *ps2);
 
-static gint gnome_print_ps2_set_color_private (GnomePrintPs2 *ps2, gdouble r, gdouble g, gdouble b);
-static gint gnome_print_ps2_set_font_private (GnomePrintPs2 *ps2, const GnomeFont *font);
+static gint gnome_print_ps2_set_color_real (GnomePrintPs2 *ps2, gdouble r, gdouble g, gdouble b);
+static gint gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *font);
 
 static gint gnome_print_ps2_print_bpath (GnomePrintPs2 *ps2, const ArtBpath *bpath);
 
 static gchar *gnome_print_ps2_get_date (void);
-static gint gnome_print_ps2_fprintf (GnomePrintPs2 *ps2, const char *format, ...);
+static gint   gnome_print_ps2_fprintf (GnomePrintPs2 *ps2, const char *format, ...);
 
 static GnomePrintContextClass *parent_class;
 
@@ -173,7 +172,7 @@ gnome_print_ps2_init (GnomePrintPs2 *ps2)
 {
 	ps2->gsave_level = 0;
 	ps2->fonts = NULL;
-	ps2->selectedfont = NULL;
+	ps2->selected_font = NULL;
 	ps2->private_color_flag = GP_GC_FLAG_UNSET;
 	ps2->pages = NULL;
 	ps2->buf = NULL;
@@ -195,6 +194,7 @@ gnome_print_ps2_finalize (GObject *object)
 		if (unlink (ps2->bufname)) {
 			g_warning ("Error unlinking buffer");
 		}
+		g_free (ps2->bufname);
 		ps2->bufname = NULL;
 	}
 
@@ -294,7 +294,7 @@ gnome_print_ps2_grestore (GnomePrintContext *ctx)
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
 	ps2->gsave_level -= 1;
-	ps2->selectedfont = NULL;
+	ps2->selected_font = NULL;
 	ps2->private_color_flag = GP_GC_FLAG_UNSET;
 
 	return gnome_print_ps2_fprintf (ps2, "Q" EOL);
@@ -308,6 +308,7 @@ gnome_print_ps2_clip (GnomePrintContext *ctx, const ArtBpath *bpath, ArtWindRule
 
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
+	/* FIXME, do we not have to set the line and color atributes here? (Chema) */
 	ret = gnome_print_ps2_print_bpath (ps2, bpath);
 	g_return_val_if_fail (ret >= 0, ret);
 
@@ -324,10 +325,11 @@ static gint
 gnome_print_ps2_fill (GnomePrintContext *ctx, const ArtBpath *bpath, ArtWindRule rule)
 {
 	GnomePrintPs2 *ps2;
-	gint ret;
+	gint ret = 0;
 
 	ps2 = GNOME_PRINT_PS2 (ctx);
 
+	/* FIXME, do we not have to set the line and color atributes here? (Chema) */
 	ret += gnome_print_ps2_set_color (ps2);
 	ret += gnome_print_ps2_print_bpath (ps2, bpath);
 
@@ -442,9 +444,9 @@ gnome_print_ps2_glyphlist (GnomePrintContext *pc, const gdouble *a, GnomeGlyphLi
 
 		ps = pgl->strings + s;
 
-		ret = gnome_print_ps2_set_font_private (ps2, gnome_rfont_get_font (ps->rfont));
+		ret = gnome_print_ps2_set_font_real (ps2, gnome_rfont_get_font (ps->rfont));
 		g_return_val_if_fail (ret >= 0, ret);
-		ret = gnome_print_ps2_set_color_private (ps2,
+		ret = gnome_print_ps2_set_color_real (ps2,
 						((ps->color >> 24) & 0xff) / 255.0,
 						((ps->color >> 16) & 0xff) / 255.0,
 						((ps->color >>  8) & 0xff) / 255.0);
@@ -457,12 +459,12 @@ gnome_print_ps2_glyphlist (GnomePrintContext *pc, const gdouble *a, GnomeGlyphLi
 
 		ret = gnome_print_ps2_fprintf (ps2, "(");
 
-		if (ps2->selectedfont->pso->encodedbytes == 1) {
+		if (ps2->selected_font->pso->encodedbytes == 1) {
 			/* 8-bit encoding */
 			for (i = ps->start; i < ps->start + ps->length; i++) {
 				gint glyph;
 				glyph = pgl->glyphs[i].glyph & 0xff;
-				gnome_font_face_pso_mark_glyph (ps2->selectedfont->pso, glyph);
+				gnome_font_face_pso_mark_glyph (ps2->selected_font->pso, glyph);
 				ret = gnome_print_ps2_fprintf (ps2, "\\%o", glyph);
 				g_return_val_if_fail (ret >= 0, ret);
 			}
@@ -470,7 +472,7 @@ gnome_print_ps2_glyphlist (GnomePrintContext *pc, const gdouble *a, GnomeGlyphLi
 			/* 16-bit encoding */
 			for (i = ps->start; i < ps->start + ps->length; i++) {
 				gint glyph, page;
-				gnome_font_face_pso_mark_glyph (ps2->selectedfont->pso, pgl->glyphs[i].glyph);
+				gnome_font_face_pso_mark_glyph (ps2->selected_font->pso, pgl->glyphs[i].glyph);
 				glyph = pgl->glyphs[i].glyph & 0xff;
 				page = (pgl->glyphs[i].glyph >> 8) & 0xff;
 				ret = gnome_print_ps2_fprintf (ps2, "\\%o\\%o", page, glyph);
@@ -498,7 +500,7 @@ gnome_print_ps2_glyphlist (GnomePrintContext *pc, const gdouble *a, GnomeGlyphLi
 	if (!identity) {
 		ret = gnome_print_ps2_fprintf (ps2, "Q" EOL);
 		g_return_val_if_fail (ret >= 0, ret);
-		ps2->selectedfont = NULL;
+		ps2->selected_font = NULL;
 		ps2->private_color_flag = GP_GC_FLAG_UNSET;
 	}
 
@@ -528,7 +530,7 @@ gnome_print_ps2_beginpage (GnomePrintContext *pc, const guchar *name)
 
 	ps2->pages = page;
 
-	ps2->selectedfont = NULL;
+	ps2->selected_font = NULL;
 	ps2->private_color_flag = GP_GC_FLAG_UNSET;
 
 	ret += gnome_print_ps2_fprintf (ps2, "%%%%Page: %s %d" EOL, name, page->number);
@@ -561,7 +563,7 @@ gnome_print_ps2_showpage (GnomePrintContext *pc)
 	if (ps2->pages)
 		ps2->pages->shown = TRUE;
 	
-	ps2->selectedfont = NULL;
+	ps2->selected_font = NULL;
 	ps2->private_color_flag = GP_GC_FLAG_UNSET;
 
 	ret += gnome_print_ps2_fprintf (ps2, "SP" EOL);
@@ -616,7 +618,7 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	/* Orientation */
 	gnome_print_transport_printf (pc->transport, "%%%%Orientation: ");
 	orientation = gnome_print_config_get (pc->config, GNOME_PRINT_KEY_ORIENTATION);
-	if (strcmp ("R0", orientation) == 0) {
+	if (!orientation || strcmp ("R0", orientation) == 0) {
 		gnome_print_transport_printf (pc->transport, "Portrait");
 	} else if (strcmp ("R90", orientation) == 0) {
 		gnome_print_transport_printf (pc->transport, "Landscape");
@@ -684,7 +686,7 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	gnome_print_transport_printf (pc->transport, ">> setpagedevice" EOL);
 	/* Download fonts */
 	for (font = ps2->fonts; font != NULL; font = font->next) {
-		gnome_font_face_pso_ensure_buffer (font->pso);
+		gnome_font_face_ps_embed (font->pso);
 		gnome_print_transport_printf (pc->transport, "%%%%BeginResource: font %s" EOL, font->pso->encodedname);
 		gnome_print_transport_write (pc->transport, font->pso->buf, font->pso->length);
 		gnome_print_transport_printf (pc->transport, "%%%%EndResource" EOL);
@@ -705,6 +707,7 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	if (unlink (ps2->bufname)) {
 		g_warning ("Error unlinking buffer");
 	}
+	g_free (ps2->bufname);
 	ps2->bufname = NULL;
 	/* END: Write buffer */
 
@@ -712,6 +715,7 @@ gnome_print_ps2_close (GnomePrintContext *pc)
 	gnome_print_transport_printf (pc->transport, "%%%%EOF" EOL);
  
  	gnome_print_transport_close (pc->transport);
+	g_object_unref (G_OBJECT (pc->transport));
 	pc->transport = NULL;
  	
 	return GNOME_PRINT_OK;
@@ -721,10 +725,18 @@ static gint
 gnome_print_ps2_set_color (GnomePrintPs2 *ps2)
 {
 	GnomePrintContext *ctx;
+	gint ret;
 
 	ctx = GNOME_PRINT_CONTEXT (ps2);
 
-	return gnome_print_ps2_set_color_private (ps2, gp_gc_get_red (ctx->gc), gp_gc_get_green (ctx->gc), gp_gc_get_blue (ctx->gc));
+	ret = gnome_print_ps2_set_color_real (ps2,
+					      gp_gc_get_red   (ctx->gc),
+					      gp_gc_get_green (ctx->gc),
+					      gp_gc_get_blue  (ctx->gc));
+
+	g_return_val_if_fail (ret == 0, ret);
+
+	return ret;
 }
 
 static gint
@@ -773,16 +785,17 @@ gnome_print_ps2_set_dash (GnomePrintPs2 *ps2)
 }
 
 static gint
-gnome_print_ps2_set_color_private (GnomePrintPs2 *ps2, gdouble r, gdouble g, gdouble b)
+gnome_print_ps2_set_color_real (GnomePrintPs2 *ps2, gdouble r, gdouble g, gdouble b)
 {
 	GnomePrintContext *ctx;
 	gint ret;
 
 	ctx = GNOME_PRINT_CONTEXT (ps2);
 
-	if ((ps2->private_color_flag == GP_GC_FLAG_CLEAR) && (r == ps2->r) && (g == ps2->g) && (b == ps2->b))
+	if ((ps2->private_color_flag == GP_GC_FLAG_CLEAR)
+	    && (r == ps2->r) && (g == ps2->g) && (b == ps2->b))
 		return GNOME_PRINT_OK;
-
+	
 	ret = gnome_print_ps2_fprintf (ps2, "%.3g %.3g %.3g rg" EOL, r, g, b);
 
 	ps2->r = r;
@@ -796,14 +809,14 @@ gnome_print_ps2_set_color_private (GnomePrintPs2 *ps2, gdouble r, gdouble g, gdo
 }
 
 static gint
-gnome_print_ps2_set_font_private (GnomePrintPs2 *ps2, const GnomeFont *gnome_font)
+gnome_print_ps2_set_font_real (GnomePrintPs2 *ps2, const GnomeFont *gnome_font)
 {
 	const GnomeFontFace *face;
 	GnomePrintPs2Font *font;
 	gint ret = 0;
 	GSList *l;
 
-	if (ps2->selectedfont && (ps2->selectedfont->face == gnome_font->face) && (ps2->selectedfont->currentsize = gnome_font->size))
+	if (ps2->selected_font && (ps2->selected_font->face == gnome_font->face) && (ps2->selected_font->currentsize = gnome_font->size))
 		return 0;
 
 	face = gnome_font_get_face (gnome_font);
@@ -834,7 +847,7 @@ gnome_print_ps2_set_font_private (GnomePrintPs2 *ps2, const GnomeFont *gnome_fon
 	ret += gnome_print_ps2_fprintf (ps2, "/%s FF %g F" EOL, font->pso->encodedname, gnome_font_get_size (gnome_font));
 
 	font->currentsize = gnome_font->size;
-	ps2->selectedfont = font;
+	ps2->selected_font = font;
 
 	g_return_val_if_fail (ret >= 0, ret);
 	
@@ -951,7 +964,7 @@ gnome_print_ps2_fprintf (GnomePrintPs2 *ps2, const char *format, ...)
 	gchar *oldlocale;
 	gint len;
 
-	oldlocale = setlocale (LC_NUMERIC, NULL);
+	oldlocale = g_strdup (setlocale (LC_NUMERIC, NULL));
 	setlocale (LC_NUMERIC, "C");
 		
  	va_start (arguments, format);
@@ -962,6 +975,7 @@ gnome_print_ps2_fprintf (GnomePrintPs2 *ps2, const char *format, ...)
 	g_free (text);
 
 	setlocale (LC_NUMERIC, oldlocale);
+	g_free (oldlocale);
 
 	return GNOME_PRINT_OK;
 }
