@@ -356,21 +356,16 @@ gpa_vendor_list_load_from_dir (GPAList *vendors, const gchar *dirname)
 GPAList *
 gpa_vendor_list_load (void)
 {
-	gchar *dirname;
-
 	if (vendors)
 		return (GPAList *) gpa_node_ref (GPA_NODE (vendors));
 
 	vendors = gpa_list_new (GPA_TYPE_VENDOR, "Vendors", FALSE);
 	g_object_weak_ref (G_OBJECT (vendors), gpa_vendors_gone, &vendors);
 
-	/* Load the user's vendors (For user installed printers) */
-	dirname = g_strdup_printf ("%s/%s", g_get_home_dir (), ".gnome/gnome-print-2.0/vendors");
-	gpa_vendor_list_load_from_dir (vendors, dirname);
-	g_free (dirname);
-
+	/* Load the user provided vendors (Implement here) */
+	
 	/* Load the system vendors */
-	gpa_vendor_list_load_from_dir (vendors, DATADIR "/gnome-print-2.0/vendors");
+	gpa_vendor_list_load_from_dir (vendors, GNOME_PRINT_DATA_DIR "/vendors");
 
 	return vendors;
 }
